@@ -1,4 +1,9 @@
-from .core import CTD as _CTD  # noqa
+"""
+Tools to load hydrographic data as pandas DataFrame with some handy methods for
+data pre-processing and analysis.
+"""
+
+
 from .plotting import plot_cast
 from .processing import (
     bindata,
@@ -12,7 +17,6 @@ from .processing import (
 )
 from .read import from_bl, from_btl, from_cnv, from_edf, from_fsi, rosette_summary
 
-
 try:
     from ._version import __version__
 except ImportError:
